=====================
 Invenio-Base v0.3.1
=====================

Invenio-Base v0.3.1 was released on October 6, 2015.

About
-----

Base package for building the Invenio application.

*This is an experimental developer preview release.*

Bug fixes
---------

- Corrects the d3.js library path.

Installation
------------

   $ pip install invenio-base==0.3.1

Documentation
-------------

   http://invenio-base.readthedocs.org/en/v0.3.1

Happy hacking and thanks for flying Invenio-Base.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-base
|   URL: http://invenio-software.org
